# r script of metabolites-790661

library("XLConnect")
library("ggplot2")
library("ggpubr")
library("corrplot")
library("ggrepel")
######################################################################################################################
# read and prepare data
akt<-readWorksheetFromFile("Table S1_Study Population and Urinary Metabolite Data.xlsx",sheet="study population data",
                            startRow=2,endRow=257)
data.ba<-akt[,c("ID","sex","age..years.","menopausal.status","lean.body.mass..g.","VO2peak..absolute..L.min.")]
colnames(data.ba)<-c("ID","sex","age","mp","LBM","VO2peak")
female<-data.ba$sex==2
Typ<-matrix(data=1,nrow=length(data.ba[,1]),ncol=1)
Typ[female]<-data.ba$mp[female]
Typ[!female]<-0
data.ba<-cbind(data.ba,Typ)
for(indnam in c("ID","sex","mp","Typ")){
  data.ba[,indnam]<-as.factor(data.ba[,indnam])
}
for(indnam in c("age","LBM","VO2peak")){
  data.ba[,indnam]<-as.numeric(data.ba[,indnam])
}
akt<-readWorksheetFromFile("Table S1_Study Population and Urinary Metabolite Data.xlsx",sheet="metabolite data",
                           startRow=2,endRow=257)
abri<-readWorksheetFromFile("Table S1_Study Population and Urinary Metabolite Data.xlsx",sheet="abbreviations_metabolites")

sova<-1
for(indnam in colnames(akt)[(sova+1):dim(akt)[2]]){
  akt[,indnam]<-as.numeric(akt[,indnam])
}
data.pr<-akt[,substr(colnames(akt),(nchar(colnames(akt))-3),nchar(colnames(akt)))==".pre"]
colnames(data.pr)<-abri$Abbreviaton
data.po<-akt[,substr(colnames(akt),(nchar(colnames(akt))-3),nchar(colnames(akt)))=="post"]
colnames(data.po)<-abri$Abbreviaton

######################################################################################################################
# compute individual fold changes, Van der Waerden Scores and residuals with respect to sex, mp, age and LBM
data.fc<-data.po/data.pr
data.pr.int<-data.pr
data.po.int<-data.po
data.fc.int<-data.fc
data.pr.intadj<-data.pr
data.po.intadj<-data.po
data.fc.intadj<-data.fc
data.ba.int<-data.ba[,c("VO2peak","sex","age","mp","LBM")]
for(indnam in c("age","LBM","VO2peak")){
  data.ba.int[,indnam]<-qnorm(rank(data.ba.int[,indnam])/(1+length(data.ba.int[,indnam])))
}
for(indnam in c("sex","mp")){
  data.ba.int[,indnam]<-as.numeric(data.ba.int[,indnam])
}
data.ba.int$mp[data.ba$mp=="n.a."]=NA
for(index in 1:47){
  y<-qnorm(rank(data.pr[,index])/(1+length(data.pr[,index])))
  data.pr.int[,index]<-y
  data.pr.intadj[,index]<-summary(lm(y~data.ba$Typ+data.ba.int$age+data.ba.int$LBM))$residuals
  y<-qnorm(rank(data.po[,index])/(1+length(data.po[,index])))
  data.po.int[,index]<-y
  data.po.intadj[,index]<-summary(lm(y~data.ba$Typ+data.ba.int$age+data.ba.int$LBM))$residuals
  y<-qnorm(rank(data.fc[,index])/(1+length(data.fc[,index])))
  data.fc.int[,index]<-y
  data.fc.intadj[,index]<-summary(lm(y~data.ba$Typ+data.ba.int$age+data.ba.int$LBM))$residuals
}
######################################################################################################################
######################################################################################################################
######################################################################################################################
# Figure 1
dataakt<-rbind(data.pr,data.po)
for(index in 1:47){
  dataakt[,index]<-qnorm(rank(dataakt[,index])/(1+length(dataakt[,index])))
}
a<-prcomp(dataakt,center=TRUE,scale.=TRUE)
b<-round(100*as.numeric(summary(a)$importance[2,]),2)
akt<-data.frame(a$x)[,1:4]
aktseq<-cbind(akt[1:255,],akt[256:510,])
colnames(aktseq)[1:4]<-paste(colnames(akt)[1:4],".SU2",sep="")
colnames(aktseq)[5:8]<-paste(colnames(akt)[1:4],".SU3",sep="")
akts<-cbind(ID=c(data.ba$ID,data.ba$ID),SU=c(rep("PRE-Exercise",255),rep("POST-Exercise",255)),akt)
g12s<-ggplot(akts,aes(x=PC1,y=PC2))+
  ggtitle("Scores")+
#  geom_text(aes(label=ID),hjust=-0.1,vjust=-0.1,size=5,data=subset(akt,SU=="POST-Exercise"))+
  geom_segment(aes(x=PC1.SU2,y=PC2.SU2,xend=PC1.SU3,yend=PC2.SU3),data=aktseq,linetype=3,size=0.5)+
  geom_point(aes(colour=SU),size=3)+
  scale_colour_manual(values=c("PRE-Exercise"="blue","POST-Exercise"="red") )+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20),title=element_text(size=25))+
  labs(colour="")+
  xlab(paste("PC1 (",b[1],"%)")) + ylab(paste("PC2 (",b[2],"%)"))

akt<-data.frame(a$rotation)[,1:4]
aktl<-cbind(nam=abri$Abbreviaton,akt)
g12l<-ggplot(aktl,aes(x=PC1,y=PC2))+
  ggtitle("Loadings")+
  geom_point(color="black",size=3)+
  geom_text(aes(label=nam),hjust=0.5,vjust=1.5,size=4.5)+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20),title=element_text(size=25))+
  labs(colour="")+
  xlab(paste("PC1 (",b[1],"%)")) + ylab(paste("PC2 (",b[2],"%)"))

g12<-ggarrange(g12s,g12l,ncol=2,nrow=1,common.legend=FALSE,legend="top")
png(file="Figure 1.png",width=1000,height=600)
g12
dev.off()
######################################################################################################################
######################################################################################################################
# Figure 2
dataakt<-cbind(data.pr.int,data.po.int)
a<-prcomp(dataakt,center=TRUE,scale.=TRUE)
b<-round(100*as.numeric(summary(a)$importance[2,]),2)
# mid.col.scale<-(median(data.ba$age)-min(data.ba$age))/(max(data.ba$age)-min(data.ba$age))
akt<-data.frame(a$x)[,1:4]
akts<-cbind(data.ba,akt)
g12s<-ggplot(akts,aes(x=PC1,y=PC2))+
  ggtitle("Scores")+
  # geom_text(aes(label=ID),hjust=-0.1,vjust=-0.1,size=5)+
  # geom_point(aes(fill=data.ba$age,shape=sex),size=3)+
  geom_point(aes(colour=sex),size=3)+
  # scale_fill_gradientn(colours=c("green","white","orange"),values=c(0,mid.col.scale,1),
  #                      breaks=c(21,50,80),labels=c("20","50","80"))+
  # scale_shape_manual(breaks=c("2","1"),values=c(24,21),labels=c("female","male"))+
  scale_colour_manual(breaks=c("2","1"),values=c("red","blue"),labels=c("female","male"))+
  # labs(fill="Age (years) ",shape="")+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20),title=element_text(size=25))+
  xlab(paste("PC1 (",b[1],"%)")) + ylab(paste("PC2 (",b[2],"%)"))

akt<-data.frame(a$rotation)[,1:4]
aktseq<-cbind(akt[1:47,],akt[48:94,])
colnames(aktseq)[1:4]<-paste(colnames(akt)[1:4],".SU2",sep="")
colnames(aktseq)[5:8]<-paste(colnames(akt)[1:4],".SU3",sep="")
aktl<-cbind(nam=abri$Abbreviaton,SU=c(rep("PRE-Exercise",47),rep("POST-Exercise",47)),akt)
g12l<-ggplot(aktl,aes(x=PC1,y=PC2))+
  ggtitle("Loadings")+
  geom_segment(aes(x=PC1.SU2,y=PC2.SU2,xend=PC1.SU3,yend=PC2.SU3),data=aktseq,linetype=3,size=0.5)+
  geom_point(aes(colour=SU),size=3)+
  geom_text(aes(label=nam),hjust=0.5,vjust=1.5,
                  data=subset(aktl,SU=="POST-Exercise" &
                  nam %in%  c("MNA","3-OH-Isov","3-Ind","Acet","Ace","Ala",
                              "Car","c-Aco","Cit","Cre","Crea","DMS","Glu","Gly","Glyc","Hip",
                              "His","Hyp","Lac","Leu","Man","Met","MSuc","DMG","Pse","Suc","Tar",
                              "Tau","Thr","t-Aco","Tri","TMAO","Ura","Urea","Val")),size=4.5)+
  geom_text(aes(label=nam),hjust=0.5,vjust=-0.5,data=subset(aktl,SU=="PRE-Exercise" &
                 nam %in%  c("2-OH-Isob","3-MXan","4-OH-Phe","BAIBA","Bet","DMA",
                             "For","Gua","MA","Pyr","Ile","Tyr")),size=4.5)+
  scale_colour_manual(values=c("PRE-Exercise"="blue","POST-Exercise"="red") )+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20),title=element_text(size=25))+
  labs(colour="")+
  xlab(paste("PC1 (",b[1],"%)")) + ylab(paste("PC2 (",b[2],"%)"))

g12<-ggarrange(g12s,g12l,ncol=2,nrow=1,common.legend=FALSE,legend="top")
png(file="Figure 2.png",width=1000,height=600)
g12
dev.off()
######################################################################################################################
######################################################################################################################
# Figure 3
dataakt<-cbind(data.ba.int[,setdiff(colnames(data.ba.int),c("sex","mp"))],data.po.int)
cor.po.int<-cor(dataakt,use="pairwise.complete.obs")
VO2peak.intadj<-summary(lm(data.ba.int$VO2peak~data.ba$Typ+data.ba.int$age+data.ba.int$LBM))$residuals
dataakt<-cbind(VO2peak=VO2peak.intadj,data.ba.int[,c("age","LBM")],data.po.intadj)
cor.po.intadj<-cor(dataakt,use="pairwise.complete.obs")
cor.po<-cor.po.int
cor.po[lower.tri(cor.po)]<-cor.po.intadj[lower.tri(cor.po.intadj)]
col3<-colorRampPalette(c("blue","white","red"))

png(file="Figure 3.png",width=900,height=900)
corrplot(cor.po,order="original",method="square",col=col3(20),na.label="-",tl.cex=1.2,cl.cex=1.2)
dev.off()
######################################################################################################################
######################################################################################################################
# Figure A1 and Table 2
dataakt<-abri
dataakt$medianFC<-apply(data.fc,2,median)
dataakt$Q1.FC<-apply(data.fc,2,quantile,probs=0.25)
dataakt$Q3.FC<-apply(data.fc,2,quantile,probs=0.75)
dataakt$wilcoxSignRank<-NA
for(index in 1:dim(abri)[1]){
  dataakt$wilcoxSignRank[index]<-wilcox.test(data.pr[,index],data.po[,index],paired=TRUE)$p.value
}
dataakt$FDR.PV.WSR<-p.adjust(dataakt$wilcoxSignRank,method="fdr")
p<-ggplot(dataakt,aes(x=log2(medianFC),y=-log10(FDR.PV.WSR)))+
  geom_hline(aes(yintercept=-log10(0.05)),colour="red",size=1.3)+
  geom_vline(aes(xintercept=-log2(1.1)),colour="blue",size=1.3)+
  geom_vline(aes(xintercept=log2(1.1)),colour="blue",size=1.3)+
  geom_text_repel(aes(label=Abbreviaton),hjust=-0.2,vjust=-0.2,size=5)+
  geom_point(size=3)+
  xlim(-0.53,2.33)+
  xlab("log2 (median FC)")+ylab("log10 (FDR-corrected p-value)")+
  ggtitle("Volcano Plot")+
  theme(axis.title=element_text(size=20),plot.title=element_text(hjust=0.5,size=25))

png(file="Figure A1.png",width=500,height=500)
p
dev.off()

writeWorksheetToFile(file="Table_2_R_output.xlsx",data=dataakt,sheet="Result")
dataakt<-cbind(Nr.=1:47,dataakt[order(-dataakt$medianFC),])
dataakt$Metabolite.<-paste(dataakt$Metabolite.," (",dataakt$Abbreviaton,")")
dataakt[,c("medianFC","Q1.FC","Q3.FC")]<-round(dataakt[,c("medianFC","Q1.FC","Q3.FC")],2)
dataakt$Q1.FC<-paste("(",dataakt$Q1.FC,", ",dataakt$Q3.FC,")")
dataakt<-dataakt[,-c(3,6,7)]
dataakt$FDR.PV.WSR<-round(dataakt$FDR.PV.WSR,4)
dataakt$FDR.PV.WSR[dataakt$FDR.PV.WSR==0]<-"<0,0001"
colnames(dataakt)<-c("Nr.","Metabolite (Abbreviaton)","Median Fold Change","(25th, 75th percentiles)",
                     "FDR-corrected p-value")
writeWorksheetToFile(file="Table_2_R_output.xlsx",data=dataakt,sheet="Table 2")
######################################################################################################################
######################################################################################################################
# Figure A2
dataakt<-cbind(data.ba.int[,setdiff(colnames(data.ba.int),c("sex","mp"))],data.pr.int)
cor.pr.int<-cor(dataakt,use="pairwise.complete.obs")
VO2peak.intadj<-summary(lm(data.ba.int$VO2peak~data.ba$Typ+data.ba.int$age+data.ba.int$LBM))$residuals
dataakt<-cbind(VO2peak=VO2peak.intadj,data.ba.int[,c("age","LBM")],data.pr.intadj)
cor.pr.intadj<-cor(dataakt,use="pairwise.complete.obs")
cor.pr<-cor.pr.int
cor.pr[lower.tri(cor.pr)]<-cor.pr.intadj[lower.tri(cor.pr.intadj)]
col3<-colorRampPalette(c("blue","white","red"))

png(file="Figure A2.png",width=900,height=900)
corrplot(cor.pr,order="original",method="square",col=col3(20),na.label="-",tl.cex=1.2,cl.cex=1.2)
dev.off()
######################################################################################################################
######################################################################################################################
# Figure A3
dataakt<-cbind(data.ba.int[,setdiff(colnames(data.ba.int),c("sex","mp"))],data.fc.int)
cor.fc.int<-cor(dataakt,use="pairwise.complete.obs")
VO2peak.intadj<-summary(lm(data.ba.int$VO2peak~data.ba$Typ+data.ba.int$age+data.ba.int$LBM))$residuals
dataakt<-cbind(VO2peak=VO2peak.intadj,data.ba.int[,c("age","LBM")],data.fc.intadj)
cor.fc.intadj<-cor(dataakt,use="pairwise.complete.obs")
cor.fc<-cor.fc.int
cor.fc[lower.tri(cor.fc)]<-cor.fc.intadj[lower.tri(cor.fc.intadj)]
col3<-colorRampPalette(c("blue","white","red"))

png(file="Figure A3.png",width=900,height=900)
corrplot(cor.fc,order="original",method="square",col=col3(20),na.label="-",tl.cex=1.2,cl.cex=1.2)
dev.off()
######################################################################################################################
######################################################################################################################
# "Figure S1_Boxplots of Urinary Metabolite Concentrations Pre- vs. Post-Exercise.pdf"
dataakt<-rbind(data.pr,data.po)
akt<-data.frame(Timepoint=factor(c(rep("Pre-Exercise",dim(data.pr)[1]),rep("Post-Exercise",dim(data.pr)[1])),
                                 levels=c("Pre-Exercise","Post-Exercise")),y=NA)
akt$Timepoint<-akt$Timepoint
plots<-list()
for(index in 1:dim(dataakt)[2]){
  akt$y<-dataakt[,index]
  plot1<-ggplot(akt,aes(x=Timepoint,y=y))+
    stat_boxplot(geom='errorbar',width=0.5)+
    geom_boxplot()+
    ggtitle(abri[index,1])+
    xlab("")+ylab("mol/L per mOsm/kg urine")+
    stat_summary(fun.y=mean,geom="point",shape=23,size=4)+
    theme(plot.title=element_text(hjust=0.5,size=14),axis.title.y=element_text(size=11),
          axis.text.x=element_text(size=12))
  plots<-append(plots,list(plot1))
}

pdf(file="Figure S1_Boxplots of Urinary Metabolite Concentrations Pre- vs. Post-Exercise.pdf",
    paper="a4",width=7,height=10)
ggarrange(plotlist=plots,nrow=3,ncol=2,common.legend=FALSE)
dev.off()
######################################################################################################################
######################################################################################################################
# "Figure S2_Boxplots of Urinary Metabolite Fold Changes.pdf"
dataakt<-data.fc
akt<-data.frame(Timepoint=c(rep("Fold Change",dim(data.fc)[1])),y=NA)
plots<-list()
for(index in 1:dim(dataakt)[2]){
  akt$y<-dataakt[,index]
  plot1<-ggplot(akt,aes(x=Timepoint,y=y))+
    stat_boxplot(geom='errorbar',width=0.5)+
    geom_boxplot()+
    ggtitle(abri[index,1])+
    xlab("")+ylab("Fold Change")+
    stat_summary(fun.y=mean,geom="point",shape=23,size=4)+
    theme(plot.title=element_text(hjust=0.5,size=14),axis.title.y=element_text(size=11),
          axis.ticks.x=element_blank(),axis.text.x=element_blank())
  plots<-append(plots,list(plot1))
}

pdf(file="Figure S2_Boxplots of Urinary Metabolite Fold Changes.pdf",paper="a4",width=7,height=10)
ggarrange(plotlist=plots,nrow=3,ncol=3,common.legend=FALSE)
dev.off()
######################################################################################################################
######################################################################################################################
######################################################################################################################
# Figure "Figure S3_Score- and Loading Plots of Principal Component Analyses"
# Figure S3a
dataakt<-rbind(data.pr,data.po)
for(index in 1:47){
  dataakt[,index]<-qnorm(rank(dataakt[,index])/(1+length(dataakt[,index])))
}
a<-prcomp(dataakt,center=TRUE,scale.=TRUE)
b<-round(100*as.numeric(summary(a)$importance[2,]),2)
######################################################################################################################
akt<-data.frame(a$x)[,1:4]
aktseq<-cbind(akt[1:255,],akt[256:510,])
colnames(aktseq)[1:4]<-paste(colnames(akt)[1:4],".SU2",sep="")
colnames(aktseq)[5:8]<-paste(colnames(akt)[1:4],".SU3",sep="")
akt<-cbind(ID=c(data.ba$ID,data.ba$ID),SU=c(rep("PRE-Exercise",255),rep("POST-Exercise",255)),akt)
g12<-ggplot(akt,aes(x=PC1,y=PC2))+
#  geom_text(aes(label=ID),hjust=-0.1,vjust=-0.1,size=5,data=subset(akt,SU=="POST-Exercise"))+
  geom_segment(aes(x=PC1.SU2,y=PC2.SU2,xend=PC1.SU3,yend=PC2.SU3),data=aktseq,linetype=3,size=0.5)+
  geom_point(aes(colour=SU),size=3)+
  scale_colour_manual(values=c("PRE-Exercise"="blue","POST-Exercise"="red") )+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20))+
  labs(colour="")+
  xlab(paste("PC1 (",b[1],"%)")) + ylab(paste("PC2 (",b[2],"%)"))
g13<-ggplot(akt,aes(x=PC1,y=PC3))+
#  geom_text(aes(label=ID),hjust=-0.1,vjust=-0.1,size=5,data=subset(akt,SU=="POST-Exercise"))+
  geom_segment(aes(x=PC1.SU2,y=PC3.SU2,xend=PC1.SU3,yend=PC3.SU3),data=aktseq,linetype=3,size=0.5)+
  geom_point(aes(colour=SU),size=3)+
  scale_colour_manual(values=c("PRE-Exercise"="blue","POST-Exercise"="red") )+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20))+
  labs(colour="")+
  xlab(paste("PC1 (",b[1],"%)"))+ylab(paste("PC3 (",b[3],"%)"))
g23<-ggplot(akt,aes(x=PC2,y=PC3))+
 # geom_text(aes(label=ID),hjust=-0.1,vjust=-0.1,size=5,data=subset(akt,SU=="POST-Exercise"))+
  geom_segment(aes(x=PC2.SU2,y=PC3.SU2,xend=PC2.SU3,yend=PC3.SU3),data=aktseq,linetype=3,size=0.5)+
  geom_point(aes(colour=SU),size=3)+
  scale_colour_manual(values=c("PRE-Exercise"="blue","POST-Exercise"="red") )+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20))+
  labs(colour="")+
  xlab(paste("PC2 (",b[2],"%)"))+ylab(paste("PC3 (",b[3],"%)"))

s3a<-ggarrange(g12,g13,g23,ncol=3,nrow=1,common.legend=TRUE,legend="top")
png(file="Figure S3a-score.png",width=1400,height=500)
s3a
dev.off()
######################################################################################################################
akt<-data.frame(a$rotation)[,1:4]
aktseq<-cbind(akt[1:47,],akt[48:94,])
colnames(aktseq)[1:4]<-paste(colnames(akt)[1:4],".SU2",sep="")
colnames(aktseq)[5:8]<-paste(colnames(akt)[1:4],".SU3",sep="")

akt<-cbind(nam=abri$Abbreviaton,akt)
g12<-ggplot(akt,aes(x=PC1,y=PC2))+
  geom_text_repel(aes(label=nam),hjust=-0.1,vjust=-0.1,size=5)+
  geom_point(color="black",size=3)+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20))+
  labs(colour="")+
  xlab(paste("PC1 (",b[1],"%)")) + ylab(paste("PC2 (",b[2],"%)"))
g13<-ggplot(akt,aes(x=PC1,y=PC3))+
  geom_text_repel(aes(label=nam),hjust=-0.1,vjust=-0.1,size=5)+
  geom_point(color="black",size=3)+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20))+
  labs(colour="")+
  xlab(paste("PC1 (",b[1],"%)")) + ylab(paste("PC3 (",b[3],"%)"))
g23<-ggplot(akt,aes(x=PC2,y=PC3))+
  geom_text_repel(aes(label=nam),hjust=-0.1,vjust=-0.1,size=5)+
  geom_point(color="black",size=3)+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20))+
  labs(colour="")+
  xlab(paste("PC2 (",b[2],"%)")) + ylab(paste("PC3 (",b[3],"%)"))
s3a<-ggarrange(g12,g13,g23,ncol=3,nrow=1,common.legend=TRUE,legend="top")
png(file="Figure S3a-loading.png",width=1400,height=500)
s3a
dev.off()
######################################################################################################################
######################################################################################################################
# Figure S3b
dataakt<-cbind(data.pr.int,data.po.int)
a<-prcomp(dataakt,center=TRUE,scale.=TRUE)
b<-round(100*as.numeric(summary(a)$importance[2,]),2)
######################################################################################################################
mid.col.scale<-(median(data.ba$age)-min(data.ba$age))/(max(data.ba$age)-min(data.ba$age))
akt<-data.frame(a$x)[,1:4]
akt<-cbind(data.ba,akt)
g12<-ggplot(akt,aes(x=PC1,y=PC2))+
  # geom_text(aes(label=ID),hjust=-0.1,vjust=-0.1,size=5)+
  # geom_point(aes(fill=data.ba$age,shape=sex),size=3)+
  geom_point(aes(colour=sex),size=3)+
  # scale_fill_gradientn(colours=c("green","white","orange"),values=c(0,mid.col.scale,1),
  #                      breaks=c(21,50,80),labels=c("20","50","80"))+
  # scale_shape_manual(breaks=c("2","1"),values=c(24,21),labels=c("female","male"))+
  scale_colour_manual(breaks=c("2","1"),values=c("red","blue"),labels=c("female","male"))+
  # labs(fill="Age (years) ",shape="")+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20),title=element_text(size=25))+
  xlab(paste("PC1 (",b[1],"%)")) + ylab(paste("PC2 (",b[2],"%)"))

g13<-ggplot(akt,aes(x=PC1,y=PC3))+
  # geom_text(aes(label=ID),hjust=-0.1,vjust=-0.1,size=5)+
  # geom_point(aes(fill=data.ba$age,shape=sex),size=3)+
  geom_point(aes(colour=sex),size=3)+
  # scale_fill_gradientn(colours=c("green","white","orange"),values=c(0,mid.col.scale,1),
  #                      breaks=c(21,50,80),labels=c("20","50","80"))+
  # scale_shape_manual(breaks=c("2","1"),values=c(24,21),labels=c("female","male"))+
  scale_colour_manual(breaks=c("2","1"),values=c("red","blue"),labels=c("female","male"))+
  # labs(fill="Age (years) ",shape="")+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20),title=element_text(size=25))+
  xlab(paste("PC1 (",b[1],"%)")) + ylab(paste("PC3 (",b[3],"%)"))
g23<-ggplot(akt,aes(x=PC2,y=PC3))+
  # geom_text(aes(label=ID),hjust=-0.1,vjust=-0.1,size=5)+
  # geom_point(aes(fill=data.ba$age,shape=sex),size=3)+
  geom_point(aes(colour=sex),size=3)+
  # scale_fill_gradientn(colours=c("green","white","orange"),values=c(0,mid.col.scale,1),
  #                      breaks=c(21,50,80),labels=c("20","50","80"))+
  # scale_shape_manual(breaks=c("2","1"),values=c(24,21),labels=c("female","male"))+
  scale_colour_manual(breaks=c("2","1"),values=c("red","blue"),labels=c("female","male"))+
  # labs(fill="Age (years) ",shape="")+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20),title=element_text(size=25))+
  xlab(paste("PC2 (",b[2],"%)")) + ylab(paste("PC3 (",b[3],"%)"))

s3b<-ggarrange(g12,g13,g23,ncol=3,nrow=1,common.legend=TRUE,legend="top")
png(file="Figure S3b-score.png",width=1400,height=500)
s3b
dev.off()
######################################################################################################################
akt<-data.frame(a$rotation)[,1:4]
aktseq<-cbind(akt[1:47,],akt[48:94,])
colnames(aktseq)[1:4]<-paste(colnames(akt)[1:4],".SU2",sep="")
colnames(aktseq)[5:8]<-paste(colnames(akt)[1:4],".SU3",sep="")
akt<-cbind(nam=abri$Abbreviaton,SU=c(rep("PRE-Exercise",47),rep("POST-Exercise",47)),akt)
g12<-ggplot(akt,aes(x=PC1,y=PC2))+
  geom_segment(aes(x=PC1.SU2,y=PC2.SU2,xend=PC1.SU3,yend=PC2.SU3),data=aktseq,linetype=3,size=0.5)+
  geom_point(aes(colour=SU),size=3)+
  geom_text(aes(label=nam),hjust=0.5,vjust=1.5,
            data=subset(akt,SU=="POST-Exercise" &
                          nam %in% c("MNA","3-OH-Isov","3-Ind","Acet","Ace","Ala",
                                     "Car","c-Aco","Cit","Cre","Crea","DMS","Glu","Gly","Glyc","Hip",
                                     "His","Hyp","Lac","Leu","Man","Met","MSuc","DMG","Pse","Suc","Tar",
                                     "Tau","Thr","t-Aco","Tri","TMAO","Ura","Urea","Val")),size=4.5)+
  geom_text(aes(label=nam),hjust=0.5,vjust=-0.5,data=subset(akt,SU=="PRE-Exercise" &
                          nam %in% c("2-OH-Isob","3-MXan","4-OH-Phe","BAIBA","Bet","DMA",
                                     "For","Gua","MA","Pyr","Ile","Tyr")),size=4.5)+
  scale_colour_manual(values=c("PRE-Exercise"="blue","POST-Exercise"="red") )+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20),title=element_text(size=25))+
  labs(colour="")+
  xlab(paste("PC1 (",b[1],"%)")) + ylab(paste("PC2 (",b[2],"%)"))
g13<-ggplot(akt,aes(x=PC1,y=PC3))+
  geom_segment(aes(x=PC1.SU2,y=PC3.SU2,xend=PC1.SU3,yend=PC3.SU3),data=aktseq,linetype=3,size=0.5)+
  geom_point(aes(colour=SU),size=3)+
  geom_text(aes(label=nam),hjust=0.5,vjust=1.5,
            data=subset(akt,SU=="POST-Exercise" &
                nam %in%  c("MNA","3-Ind","3-MXan","Acet","Ace","Ala",
                            "Bet","Car","c-Aco","Cre","Crea","DMA","For","Glu","Gly","Glyc","Gua","Hip",
                            "Hyp","Man","Met","MA","DMG",
                            "Tau","Tri","TMAO","Tyr","Ura","Urea")),size=4.5)+
  geom_text(aes(label=nam),hjust=0.5,vjust=-0.5,data=subset(akt,SU=="PRE-Exercise" &
                          nam %in%  c("2-OH-Isob","3-OH-Isov","4-OH-Phe","BAIBA","Cit","DMS","His","Ile","Lac","Leu",
                                      "MSuc","Pse","Pyr","Suc","t-Aco","Tar","Thr","Val")),size=4.5)+
  scale_colour_manual(values=c("PRE-Exercise"="blue","POST-Exercise"="red") )+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20),title=element_text(size=25))+
  labs(colour="")+
  xlab(paste("PC1 (",b[1],"%)")) + ylab(paste("PC3 (",b[3],"%)"))

g23<-ggplot(akt,aes(x=PC2,y=PC3))+
  geom_segment(aes(x=PC2.SU2,y=PC3.SU2,xend=PC2.SU3,yend=PC3.SU3),data=aktseq,linetype=3,size=0.5)+
  geom_point(aes(colour=SU),size=3)+
  geom_text(aes(label=nam),hjust=1.2,vjust=0.5,
            data=subset(akt,SU=="POST-Exercise" &
                          nam %in%  c("MNA","2-OH-Isob","3-Ind","3-MXan","Ace",
                                      "Car","c-Aco","DMS","For","Glu","Gly","Glyc","Gua","Hip",
                                      "His","Hyp","Ile","Lac","Met","MA","MSuc","DMG","Pse","Pyr","Suc","Tar",
                                      "Tau","Thr","Tri","TMAO","Tyr","Urea","Val")),size=4.5)+
  geom_text(aes(label=nam),hjust=-0.2,vjust=0.5,data=subset(akt,SU=="PRE-Exercise" &
                          nam %in%  c("3-OH-Isov","4-OH-Phe","Acet","Ala","BAIBA","Bet","Cit","Cre","Crea","DMA"
                                      ,"Leu","Man","t-Aco","Ura")),size=4.5)+
  scale_colour_manual(values=c("PRE-Exercise"="blue","POST-Exercise"="red") )+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20),title=element_text(size=25))+
  labs(colour="")+
  xlim(c(-0.25,0.25))+
  xlab(paste("PC2 (",b[2],"%)")) + ylab(paste("PC3 (",b[3],"%)"))
s3b<-ggarrange(g12,g13,g23,ncol=3,nrow=1,common.legend=TRUE,legend="top")
png(file="Figure S3b-loading.png",width=1400,height=500)
s3b
dev.off()
######################################################################################################################
######################################################################################################################
# Figure S3c
dataakt<-data.pr.intadj
mid.col.scale<-(median(data.ba$VO2peak)-min(data.ba$VO2peak))/(max(data.ba$VO2peak)-min(data.ba$VO2peak))
a<-prcomp(dataakt,center=TRUE,scale.=TRUE)
b<-round(100*as.numeric(summary(a)$importance[2,]),2)
akt<-data.frame(a$x)[,1:4]
akt<-cbind(data.ba,akt)
g12<-ggplot(akt,aes(x=PC1,y=PC2))+
#  geom_text(aes(label=ID),hjust=-0.1,vjust=-0.1,size=5)+
  geom_point(aes(fill=data.ba$VO2peak,shape=Typ),size=4)+
  scale_fill_gradientn(colours=c("green","white","orange"),values=c(0,mid.col.scale,1))+
  scale_shape_manual(breaks=c("1","2","0"),values=c(25,24,21),labels=c("premenopausal","postmenopausal","male"))+
  labs(fill="VO2peak (L/min) ",shape="")+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20))+
  xlab(paste("PC1 (",b[1],"%)")) + ylab(paste("PC2 (",b[2],"%)"))
g13<-ggplot(akt,aes(x=PC1,y=PC3))+
#  geom_text(aes(label=ID),hjust=-0.1,vjust=-0.1,size=5)+
  geom_point(aes(fill=data.ba$VO2peak,shape=Typ),size=4)+
  scale_fill_gradientn(colours=c("green","white","orange"),values=c(0,mid.col.scale,1))+
  scale_shape_manual(breaks=c("1","2","0"),values=c(25,24,21),labels=c("premenopausal","postmenopausal","male"))+
  labs(fill="VO2peak (L/min)",shape="")+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20))+
  xlab(paste("PC1 (",b[1],"%)")) + ylab(paste("PC3 (",b[3],"%)"))
g23<-ggplot(akt,aes(x=PC2,y=PC3))+
#  geom_text(aes(label=ID),hjust=-0.1,vjust=-0.1,size=5)+
  geom_point(aes(fill=data.ba$VO2peak,shape=Typ),size=4)+
  scale_fill_gradientn(colours=c("green","white","orange"),values=c(0,mid.col.scale,1))+
  scale_shape_manual(breaks=c("1","2","0"),values=c(25,24,21),labels=c("premenopausal","postmenopausal","male"))+
  labs(fill="VO2peak (L/min)",shape="")+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20))+
  xlab(paste("PC2 (",b[2],"%)")) + ylab(paste("PC3 (",b[3],"%)"))

s3c<-ggarrange(g12,g13,g23,ncol=3,nrow=1,common.legend=TRUE,legend="top")
png(file="Figure S3c-score.png",width=1400,height=500)
s3c
dev.off()
######################################################################################################################
akt<-data.frame(a$rotation)[,1:4]
akt<-cbind(nam=abri$Abbreviaton,akt)
g12<-ggplot(akt,aes(x=PC1,y=PC2))+
  geom_point(color="black",size=3)+
  geom_text_repel(aes(label=nam),hjust=0.5,vjust=1.5,size=4.5)+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20),title=element_text(size=25))+
  labs(colour="")+
  xlab(paste("PC1 (",b[1],"%)")) + ylab(paste("PC2 (",b[2],"%)"))
g13<-ggplot(akt,aes(x=PC1,y=PC3))+
  geom_point(color="black",size=3)+
  geom_text_repel(aes(label=nam),hjust=0.5,vjust=1.5,size=4.5)+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20),title=element_text(size=25))+
  labs(colour="")+
  xlab(paste("PC1 (",b[1],"%)")) + ylab(paste("PC3 (",b[3],"%)"))
g23<-ggplot(akt,aes(x=PC2,y=PC3))+
  geom_point(color="black",size=3)+
  geom_text_repel(aes(label=nam),hjust=0.5,vjust=1.5,size=4.5)+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20),title=element_text(size=25))+
  labs(colour="")+
  xlab(paste("PC2 (",b[2],"%)")) + ylab(paste("PC3 (",b[3],"%)"))

s3c<-ggarrange(g12,g13,g23,ncol=3,nrow=1,common.legend=TRUE,legend="top")
png(file="Figure S3c-loading.png",width=1400,height=500)
s3c
dev.off()
######################################################################################################################
######################################################################################################################
# Figure S3d
dataakt<-data.po.intadj
mid.col.scale<-(median(data.ba$VO2peak)-min(data.ba$VO2peak))/(max(data.ba$VO2peak)-min(data.ba$VO2peak))
a<-prcomp(dataakt,center=TRUE,scale.=TRUE)
b<-round(100*as.numeric(summary(a)$importance[2,]),2)
akt<-data.frame(a$x)[,1:4]
akt<-cbind(data.ba,akt)
g12<-ggplot(akt,aes(x=PC1,y=PC2))+
#  geom_text(aes(label=ID),hjust=-0.1,vjust=-0.1,size=5)+
  geom_point(aes(fill=data.ba$VO2peak,shape=Typ),size=4)+
  scale_fill_gradientn(colours=c("green","white","orange"),values=c(0,mid.col.scale,1))+
  scale_shape_manual(breaks=c("1","2","0"),values=c(25,24,21),labels=c("premenopausal","postmenopausal","male"))+
  labs(fill="VO2peak (L/min) ",shape="")+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20))+
  xlab(paste("PC1 (",b[1],"%)")) + ylab(paste("PC2 (",b[2],"%)"))
g13<-ggplot(akt,aes(x=PC1,y=PC3))+
#  geom_text(aes(label=ID),hjust=-0.1,vjust=-0.1,size=5)+
  geom_point(aes(fill=data.ba$VO2peak,shape=Typ),size=4)+
  scale_fill_gradientn(colours=c("green","white","orange"),values=c(0,mid.col.scale,1))+
  scale_shape_manual(breaks=c("1","2","0"),values=c(25,24,21),labels=c("premenopausal","postmenopausal","male"))+
  labs(fill="VO2peak (L/min)",shape="")+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20))+
  xlab(paste("PC1 (",b[1],"%)")) + ylab(paste("PC3 (",b[3],"%)"))
g23<-ggplot(akt,aes(x=PC2,y=PC3))+
#  geom_text(aes(label=ID),hjust=-0.1,vjust=-0.1,size=5)+
  geom_point(aes(fill=data.ba$VO2peak,shape=Typ),size=4)+
  scale_fill_gradientn(colours=c("green","white","orange"),values=c(0,mid.col.scale,1))+
  scale_shape_manual(breaks=c("1","2","0"),values=c(25,24,21),labels=c("premenopausal","postmenopausal","male"))+
  labs(fill="VO2peak (L/min)",shape="")+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20))+
  xlab(paste("PC2 (",b[2],"%)")) + ylab(paste("PC3 (",b[3],"%)"))

s3d<-ggarrange(g12,g13,g23,ncol=3,nrow=1,common.legend=TRUE,legend="top")
png(file="Figure S3d-score.png",width=1400,height=500)
s3d
dev.off()
######################################################################################################################
akt<-data.frame(a$rotation)[,1:4]
akt<-cbind(nam=abri$Abbreviaton,akt)
g12<-ggplot(akt,aes(x=PC1,y=PC2))+
  geom_point(color="black",size=3)+
  geom_text_repel(aes(label=nam),hjust=0.5,vjust=1.5,size=4.5)+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20),title=element_text(size=25))+
  labs(colour="")+
  xlab(paste("PC1 (",b[1],"%)")) + ylab(paste("PC2 (",b[2],"%)"))
g13<-ggplot(akt,aes(x=PC1,y=PC3))+
  geom_point(color="black",size=3)+
  geom_text_repel(aes(label=nam),hjust=0.5,vjust=1.5,size=4.5)+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20),title=element_text(size=25))+
  labs(colour="")+
  xlab(paste("PC1 (",b[1],"%)")) + ylab(paste("PC3 (",b[3],"%)"))
g23<-ggplot(akt,aes(x=PC2,y=PC3))+
  geom_point(color="black",size=3)+
  geom_text_repel(aes(label=nam),hjust=0.5,vjust=1.5,size=4.5)+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20),title=element_text(size=25))+
  labs(colour="")+
  xlab(paste("PC2 (",b[2],"%)")) + ylab(paste("PC3 (",b[3],"%)"))

s3d<-ggarrange(g12,g13,g23,ncol=3,nrow=1,common.legend=TRUE,legend="top")
png(file="Figure S3d-loading.png",width=1400,height=500)
s3d
dev.off()
######################################################################################################################
######################################################################################################################
# Figure S3e
dataakt<-data.fc.intadj
mid.col.scale<-(median(data.ba$VO2peak)-min(data.ba$VO2peak))/(max(data.ba$VO2peak)-min(data.ba$VO2peak))
a<-prcomp(dataakt,center=TRUE,scale.=TRUE)
b<-round(100*as.numeric(summary(a)$importance[2,]),2)
akt<-data.frame(a$x)[,1:4]
akt<-cbind(data.ba,akt)
g12<-ggplot(akt,aes(x=PC1,y=PC2))+
#  geom_text(aes(label=ID),hjust=-0.1,vjust=-0.1,size=5)+
  geom_point(aes(fill=data.ba$VO2peak,shape=Typ),size=4)+
  scale_fill_gradientn(colours=c("green","white","orange"),values=c(0,mid.col.scale,1))+
  scale_shape_manual(breaks=c("1","2","0"),values=c(25,24,21),labels=c("premenopausal","postmenopausal","male"))+
  labs(fill="VO2peak (L/min) ",shape="")+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20))+
  xlab(paste("PC1 (",b[1],"%)")) + ylab(paste("PC2 (",b[2],"%)"))
g13<-ggplot(akt,aes(x=PC1,y=PC3))+
#  geom_text(aes(label=ID),hjust=-0.1,vjust=-0.1,size=5)+
  geom_point(aes(fill=data.ba$VO2peak,shape=Typ),size=4)+
  scale_fill_gradientn(colours=c("green","white","orange"),values=c(0,mid.col.scale,1))+
  scale_shape_manual(breaks=c("1","2","0"),values=c(25,24,21),labels=c("premenopausal","postmenopausal","male"))+
  labs(fill="VO2peak (L/min)",shape="")+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20))+
  xlab(paste("PC1 (",b[1],"%)")) + ylab(paste("PC3 (",b[3],"%)"))
g23<-ggplot(akt,aes(x=PC2,y=PC3))+
#  geom_text(aes(label=ID),hjust=-0.1,vjust=-0.1,size=5)+
  geom_point(aes(fill=data.ba$VO2peak,shape=Typ),size=4)+
  scale_fill_gradientn(colours=c("green","white","orange"),values=c(0,mid.col.scale,1))+
  scale_shape_manual(breaks=c("1","2","0"),values=c(25,24,21),labels=c("premenopausal","postmenopausal","male"))+
  labs(fill="VO2peak (L/min)",shape="")+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20))+
  xlab(paste("PC2 (",b[2],"%)")) + ylab(paste("PC3 (",b[3],"%)"))

s3e<-ggarrange(g12,g13,g23,ncol=3,nrow=1,common.legend=TRUE,legend="top")
png(file="Figure S3e-score.png",width=1400,height=500)
s3e
dev.off()
######################################################################################################################
akt<-data.frame(a$rotation)[,1:4]
akt<-cbind(nam=abri$Abbreviaton,akt)
g12<-ggplot(akt,aes(x=PC1,y=PC2))+
  geom_point(color="black",size=3)+
  geom_text_repel(aes(label=nam),hjust=0.5,vjust=1.5,size=4.5)+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20),title=element_text(size=25))+
  labs(colour="")+
  xlab(paste("PC1 (",b[1],"%)")) + ylab(paste("PC2 (",b[2],"%)"))
g13<-ggplot(akt,aes(x=PC1,y=PC3))+
  geom_point(color="black",size=3)+
  geom_text_repel(aes(label=nam),hjust=0.5,vjust=1.5,size=4.5)+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20),title=element_text(size=25))+
  labs(colour="")+
  xlab(paste("PC1 (",b[1],"%)")) + ylab(paste("PC3 (",b[3],"%)"))
g23<-ggplot(akt,aes(x=PC2,y=PC3))+
  geom_point(color="black",size=3)+
  geom_text_repel(aes(label=nam),hjust=0.5,vjust=1.5,size=4.5)+
  theme(legend.position="top",legend.title=element_text(size=20),legend.text=element_text(size=20),
        axis.title=element_text(size=20),title=element_text(size=25))+
  labs(colour="")+
  xlab(paste("PC2 (",b[2],"%)")) + ylab(paste("PC3 (",b[3],"%)"))

s3e<-ggarrange(g12,g13,g23,ncol=3,nrow=1,common.legend=TRUE,legend="top")
png(file="Figure S3e-loading.png",width=1400,height=500)
s3e
dev.off()